/* BEGIN_OF manual part of ccm script file (important, change with care):
// staggered dimer (J-J') model with spiral model state (see Sven E. Krueger)
// written by Sven Krueger
//
// control parameters
output level= 1
find generalised expectation values= 0
work directory=  dummy_obsoleteOption
output file=     dummy_obsoleteOption
// solve parameters now
minimum=        -1.50
maximum=         0.00
increment=       0.10
minimumy=        0.00
maximumy=        5.00
// other higher level parameters
dimension=  2
spin=       0.5
bounding=  10
n=    4
m=    4
bonds=    2
restriction=1  // 1=no restriction, 2=even flips, 3=user defined, 4=lenght>1
solution strategy=1 // 1=NewtRaphson(seriell), 2=DirectIt(parallel)
// the unit cell
number=2
       0.0        0.0        0.0        0.5
       1.0        0.0        0.0        0.5
// the Bravais lattice
=      2.0        0.0        0.0
       1.0        1.0        0.0
       0.0        0.0        1.0
//  Bravis: (2,0),(1,1)
//  unit cell (with bravis):
//     ---------     bond Delta (***): between 1 und 2  within unit cell
//   /  1***2  /   
//   ---------
//     x= -2.0 -1.0  0.0  1.0  2.0
//
//y=1.0:    2----1****2----1****2
//          |    |    |    |    |
//  0.0:    1****2----1****2----1
//          |    |    |    |    |
// -1.0:    2--- 1****2----1****2
//
// END_OF manual part of ccm script file
*/

#include <math.h>

int n_si = 2;    /* number of sites in unit cell */
int n_nn = 4;    /* number of nearest neighb. of each site */
int digits = 15; /* number of digits in float numbers, max 15 */
int directional;

#define Phi   0.2  /* value of model state parameter Phi */
#define Jp    1.0  /* J', here 1.0 because it is the parameter */
struct {
  int nn[4];     /* transl x y z (bravis base) idx_site_inUnitCell */
  double angle;  /* angle between spins separated by transl vector */
  double value;  /* value of the bond */
  int direct;    /* directionality:  1: -->    -1: <-- */
//  int rev_idx;   /* index of same bond in reverse direction; only for directional=1 */
} bond[50] = { { { 0, 0, 0,  2}, M_PI+3.0*Phi, Jp,   1 }, // nearest neighb of site 1 (to site 2)
               { {-1, 1, 0,  2}, M_PI+Phi,     1.0,  1 },
               { {-1, 0, 0,  2}, M_PI-Phi,     1.0,  1 }, // oder direct=-1(wegen -Phi)
               { { 0,-1, 0,  2}, M_PI+Phi,     1.0,  1 },
               { { 1, 0, 0,  1}, M_PI-Phi,     1.0, -1 }, // oder direct=+1(wegen -Phi), nn of site 2 (to site 1)
               { { 0, 1, 0,  1}, M_PI+Phi,     1.0, -1 }, // neg.Winkel da direct*winkel muss positiv sein
               { { 0, 0, 0,  1}, M_PI+3.0*Phi, Jp,  -1 },
               { { 1,-1, 0,  1}, M_PI+Phi,     1.0, -1 },};

#include "ccm_genScript2.c"

int main(int argc, char *argv[])
{ int i,si; double tr[2] = {0.0, 0.0}; char str[200];

  setvbuf(stdout,(char*)NULL,_IONBF,0);    /* everything with fflush(stdout) */

  sprintf(str,"grep -v \"sprintf(str\" %s|grep -B 1000 END_OF|grep -v BEGIN_OF",__FILE__);
  system(str);
    
  printf("//\n// here starts AUTOMATIC generation by %s:\n",__FILE__);
  printf("//\n// ***** NOTE: Phi = %s  *****\n//\n",print_frac(Phi/M_PI,str));
  printf("// the nearest-neighbours to each site in the unit cell\n");
  printf("// translation  x y z  (in bravis base)   idx_site_inUnitCell\n");
  for (si=1;si<=n_si;si++) {
    printf("number=  %d  // nn of site %d\n",n_nn,si);
    for (i=0;i<n_nn;i++) {print_nn(si,i); printf("\n");}
  }

  printf("// symmetry operations in Cartesian coordinates\n");
  printf("// point symmetry (3x3 matrix)   translation vector\n");
  printf("number= 2\n");
  rot(0.0,tr,"");               // x-->x,      y-->y
  ref(0.0,tr,"refl x-axis");    // x-->x,      y-->(-y)
  
  printf("// Information regardin the Hamiltonian in terms of:\n");
  printf("// Hamiltonian types.\n");
  directional=1;  /* has to be 0 or 1 */
  printf("directional=%d\n",directional);
  printf("// first the bonds concerning the parameter Delta (here J')\n");
  print_term("J' bond site 1",1,"1000",1); // only 1st nn of site 1
  print_term("J' bond site 2",2,"0010",1);
  printf("// now the bonds concerning J\n");
  print_term("J bond site 1",1,"0111",1); // 2nd, 3th, and 4th nn of site 1
  print_term("J bond site 2",2,"1101",1);

  
  return 0;
}
